@@ -1,6 +1,22 @@
 use crate::*;
 use fixed;
 
+macro_rules! impl_mixed_num_conversion{
+    ( $T1:ty, $T2:ty ) => {
+        impl MixedNumConversion<$T2> for $T1
+        {
+            #[inline(always)]
+            fn mixed_from_num( number:$T2 ) -> Self {
+                return Self::from_num(number);
+            }
+            #[inline(always)]
+            fn mixed_to_num( &self ) -> $T2 {
+                return self.to_num::<$T2>();
+            }
+        }
+    }
+}
+
 macro_rules! impl_mixed_num_for_fixed{
     ( $T:ty ) => {
 
@@ -8,29 +24,25 @@ macro_rules! impl_mixed_num_for_fixed{
         {
         }
 
-        impl MixedNumConversion<f32> for $T
-        {
-            #[inline(always)]
-            fn mixed_from_num( number:f32 ) -> Self {
-                return Self::from_num(number);
-            }
-            #[inline(always)]
-            fn mixed_to_num( &self ) -> f32 {
-                return self.to_num::<f32>();
-            }
-        }
+        impl_mixed_num_conversion!($T, f32);
+        impl_mixed_num_conversion!($T, f64);
+        
+        impl_mixed_num_conversion!($T, usize);
+        impl_mixed_num_conversion!($T, isize);
+        
+        impl_mixed_num_conversion!($T, u8);
+        impl_mixed_num_conversion!($T, u16);
+        impl_mixed_num_conversion!($T, u32);
+        impl_mixed_num_conversion!($T, u64);
+        impl_mixed_num_conversion!($T, u128);
 
-        impl MixedNumConversion<f64> for $T
-        {
-            #[inline(always)]
-            fn mixed_from_num( number:f64 ) -> Self {
-                return Self::from_num(number);
-            }
-            #[inline(always)]
-            fn mixed_to_num( &self ) -> f64 {
-                return self.to_num::<f64>();
-            }
-        }
+        impl_mixed_num_conversion!($T, i8);
+        impl_mixed_num_conversion!($T, i16);
+        impl_mixed_num_conversion!($T, i32);
+        impl_mixed_num_conversion!($T, i64);
+        impl_mixed_num_conversion!($T, i128);
+
+        
         /*
         impl MixedNumConversion<Cartesian<$T>> for $T
         {
@@ -72,54 +84,6 @@ macro_rules! impl_mixed_num_for_fixed{
         }
         */
 
-        impl MixedNumConversion<u32> for $T
-        {
-            #[inline(always)]
-            fn mixed_from_num( number:u32 ) -> Self {
-                return Self::from_num(number);
-            }
-            #[inline(always)]
-            fn mixed_to_num( &self ) -> u32 {
-                return self.to_num::<u32>();
-            }
-        }
-
-        impl MixedNumConversion<u64> for $T
-        {
-            #[inline(always)]
-            fn mixed_from_num( number:u64 ) -> Self {
-                return Self::from_num(number);
-            }
-            #[inline(always)]
-            fn mixed_to_num( &self ) -> u64 {
-                return self.to_num::<u64>();
-            }
-        }
-
-        impl MixedNumConversion<i32> for $T
-        {
-            #[inline(always)]
-            fn mixed_from_num( number:i32 ) -> Self {
-                return Self::from_num(number);
-            }
-            #[inline(always)]
-            fn mixed_to_num( &self ) -> i32 {
-                return self.to_num::<i32>();
-            }
-        }
-
-        impl MixedNumConversion<i64> for $T
-        {
-            #[inline(always)]
-            fn mixed_from_num( number:i64 ) -> Self {
-                return Self::from_num(number);
-            }
-            #[inline(always)]
-            fn mixed_to_num( &self ) -> i64 {
-                return self.to_num::<i64>();
-            }
-        }
-
         impl MixedPi for $T
         {
             #[inline(always)]
